pub(crate) enum ParserPackCommand {
Verify {
archive: PathBuf,
},
Install {
archive: PathBuf,
},
Enable {
artifact: String,
},
Update {
archive: PathBuf,
},
Disable,
Remove,
Status,
}Expand description
Explicit optional parser-pack lifecycle commands.
Variants
Verify
Validate a local completed archive without installing it.
Install
Install a local completed archive without enabling it.
Enable
Enable one explicitly named installed artifact for this project.
Selecting the artifact reported by status.rollback performs an explicit rollback.
Update
Install and atomically select a replacement while retaining rollback identity.
Disable
Disable the optional pack for this project without deleting installed slots.
Remove
Disable this project and remove this logical pack’s user-owned slots.
Status
Print bounded content-free lifecycle state.