SymbolsCommand

Enum SymbolsCommand 

pub(crate) enum SymbolsCommand {
    Build {
        path: PathBuf,
        max_bytes: u64,
        max_workers: Option<usize>,
        timeout_seconds: Option<u64>,
    },
    List {
        file: Option<String>,
        query: Option<String>,
        limit: usize,
    },
    Relations {
        view: RelationViewArg,
        file: Option<String>,
        query: Option<String>,
        detailed: Box<DetailedRelationArgs>,
        limit: usize,
    },
    Slice {
        file: PathBuf,
        selector: RequiredSymbolSelectorArgs,
    },
}
Symbol graph subcommands.

Variants



Build

Rebuild symbols for indexed files.

Fields

path: PathBuf

Repository root used to read indexed files.

max_bytes: u64

Maximum file size parsed for symbols.

max_workers: Option<usize>

Maximum parser worker threads. Defaults to Rayon automatic sizing.

timeout_seconds: Option<u64>

Stop starting parser work after this many seconds.



List

List symbols by optional file and query.

Fields

file: Option<String>

Optional repository-relative file path.

query: Option<String>

Optional symbol or signature query.

limit: usize

Maximum symbols to return.



Relations

List symbol relations by optional file and query.

Fields

view: RelationViewArg

Preserve legacy rows or opt in to detailed normalized-graph navigation.

file: Option<String>

Optional repository-relative file path.

query: Option<String>

Optional source, target, or context query.

detailed: Box<DetailedRelationArgs>

Additive normalized-graph traversal controls.

limit: usize

Maximum relations to return.



Slice

Return an exact source slice for a named symbol.

Fields

file: PathBuf

Repository-relative file path.

selector: RequiredSymbolSelectorArgs

Exact declaration selector.