pub(crate) fn load_cli_atlas_config(
cli: &Cli,
) -> Result<AtlasMapConfig, CliError>Expand description
Load map and lint config with an explicit CLI database override when present.
pub(crate) fn load_cli_atlas_config(
cli: &Cli,
) -> Result<AtlasMapConfig, CliError>Load map and lint config with an explicit CLI database override when present.