pub(crate) fn load_token_atlas_preview(store: &AtlasStore) -> TokenAtlasPreviewExpand description
Load the tiny optional atlas preview through existing indexed relation-family reads.
pub(crate) fn load_token_atlas_preview(store: &AtlasStore) -> TokenAtlasPreviewLoad the tiny optional atlas preview through existing indexed relation-family reads.