pub(crate) fn open_index_for_read(cli: &Cli) -> Result<AtlasStore, CliError>Expand description
Open and verify the durable index before a normal CLI read.
pub(crate) fn open_index_for_read(cli: &Cli) -> Result<AtlasStore, CliError>Open and verify the durable index before a normal CLI read.