pub(crate) struct DetailedRelationAnchorArgs {
pub(crate) symbol: Option<String>,
pub(crate) symbol_parent: Option<String>,
pub(crate) symbol_kind: Option<String>,
pub(crate) symbol_signature: Option<String>,
}Expand description
Exact local anchor controls for detailed relation navigation.
Fields
symbol: Option<String>Exact symbol name used as the detailed anchor; omit for a file anchor.
symbol_parent: Option<String>Optional exact parent used to disambiguate the detailed symbol anchor.
symbol_kind: Option<String>Optional exact kind used to disambiguate the detailed symbol anchor.
symbol_signature: Option<String>Optional exact signature used to disambiguate the detailed symbol anchor.