pub(crate) struct HealthReportArgs {Show 13 fields
pub(crate) start_index: usize,
pub(crate) limit: usize,
pub(crate) category: Option<String>,
pub(crate) severity: Option<HealthSeverityArg>,
pub(crate) path_prefix: Option<String>,
pub(crate) summary_only: bool,
pub(crate) source_only: bool,
pub(crate) coverage: bool,
pub(crate) parser: Option<String>,
pub(crate) provider: Option<String>,
pub(crate) relation: Option<String>,
pub(crate) coverage_state: Option<String>,
pub(crate) reason: Option<String>,
}Expand description
Read-only health report filters shared by health and health-check.
Fields
start_index: usizePagination start index after filters are applied.
limit: usizeMaximum findings to return.
category: Option<String>Optional finding category filter.
severity: Option<HealthSeverityArg>Optional severity filter.
path_prefix: Option<String>Optional repository-relative primary or related path prefix.
summary_only: boolReturn counts and paging metadata without finding rows.
source_only: boolRestrict findings to source files and folders that contain source files.
coverage: boolOpt in to bounded current coverage discovery instead of structural findings.
parser: Option<String>Optional source parser coverage filter.
provider: Option<String>Optional derived-fact provider coverage filter.
relation: Option<String>Optional relationship-family coverage filter.
coverage_state: Option<String>Optional complete, no_candidates, partial, failed, ignored, oversized, quarantined, or stale filter.
reason: Option<String>Optional exact coverage reason filter.