pub(crate) enum CliError {
Show 19 variants
IndexWork(IndexWorkFailure),
Db(DbError),
Service(ServiceError),
Fs(FsError),
Io {
path: PathBuf,
source: Error,
},
Output(Error),
Json(Error),
Mcp(String),
Watcher(String),
AtlasMap(AtlasMapError),
ParserPack(OptionalParserPackLifecycleError),
OptionalParserOperationAndCleanup {
operation: Box<Self>,
cleanup: Box<Self>,
},
InvalidInput(String),
InitRequired(Box<IndexInitRequired>),
WorktreeRequired(Box<ProjectWorktreeRequired>),
RefreshRequired(Box<IndexRefreshRequired>),
VerificationIncomplete(Box<IndexVerificationIncomplete>),
ProjectMismatch(Box<IndexProjectMismatch>),
RootTransitionFollowup {
root: String,
transition: RootTransition,
source: Box<CliError>,
},
}Expand description
Error type for CLI boundary failures.
Variants
IndexWork(IndexWorkFailure)
Cooperative index work was canceled or exceeded a declared bound.
Db(DbError)
Database operation failed.
Service(ServiceError)
Shared service operation failed.
Fs(FsError)
Filesystem scanner operation failed.
Io
File or directory operation failed.
Output(Error)
Output stream write failed.
Json(Error)
JSON serialization failed.
Mcp(String)
MCP runtime failed.
Watcher(String)
Watcher runtime failed.
AtlasMap(AtlasMapError)
Atlas map operation failed.
ParserPack(OptionalParserPackLifecycleError)
Optional parser-pack lifecycle operation failed.
OptionalParserOperationAndCleanup
Optional parsing failed and the requested process cleanup also failed.
Fields
InvalidInput(String)
User input was invalid.
InitRequired(Box<IndexInitRequired>)
The selected source root has not been initialized.
WorktreeRequired(Box<ProjectWorktreeRequired>)
A bare/common Git directory was selected instead of checked-out source.
RefreshRequired(Box<IndexRefreshRequired>)
Current local source differs from the durable index.
VerificationIncomplete(Box<IndexVerificationIncomplete>)
Current local source could not be verified completely.
ProjectMismatch(Box<IndexProjectMismatch>)
The selected project root does not own the opened index.
RootTransitionFollowup
A durable root transition committed before generated configuration failed.