pub(crate) enum SymbolsCommand {
Build {
path: PathBuf,
max_bytes: u64,
max_workers: Option<usize>,
timeout_seconds: Option<u64>,
},
List {
file: Option<String>,
query: Option<String>,
limit: usize,
},
Relations {
view: RelationViewArg,
file: Option<String>,
query: Option<String>,
detailed: Box<DetailedRelationArgs>,
limit: usize,
},
Slice {
file: PathBuf,
selector: RequiredSymbolSelectorArgs,
},
}Expand description
Symbol graph subcommands.
Variants
Build
Rebuild symbols for indexed files.
Fields
List
List symbols by optional file and query.
Fields
Relations
List symbol relations by optional file and query.
Fields

view: RelationViewArgPreserve legacy rows or opt in to detailed normalized-graph navigation.

detailed: Box<DetailedRelationArgs>Additive normalized-graph traversal controls.
Slice
Return an exact source slice for a named symbol.
Fields

selector: RequiredSymbolSelectorArgsExact declaration selector.